@@ -29,6 +29,7 @@ from botocore.credentials import (
     SharedCredentialProvider,
     SSOCredentialFetcher,
     SSOProvider,
+    _get_client_creator,
     create_credential_resolver,
     create_mfa_serial_refresher,
     get_credentials,
@@ -109,6 +110,7 @@ from botocore.utils import (
     S3ExpressIdentityResolver,
     S3RegionRedirector,
     S3RegionRedirectorv2,
+    create_nested_client,
 )
 from botocore.waiter import (
     NormalizedOperationMethod,
@@ -179,7 +181,7 @@ def test_protocol_parsers():
         (
             ClientCreator.create_client,
             {
-                '7a95dd4939bcabf79704f3e928ab4dcf079b5e58',
+                '1c27be7d1b4374887620be970dca01a9fecf9632',
             },
         ),
         (
@@ -216,7 +218,7 @@ def test_protocol_parsers():
         (
             ClientCreator._register_retries,
             {
-                '16d3064142e5f9e45b0094bbfabf7be30183f255',
+                'ceecfc40a4ffa83551d7e6f63fd5d17f820664b0',
             },
         ),
         (
@@ -241,7 +243,7 @@ def test_protocol_parsers():
         (
             BaseClient._make_api_call.__wrapped__,
             {
-                '549e7d9de202ea48ff9e87f6006c95e515ecbd73',
+                '44a1fbef21dc588a7976510c3540c5a51350aa11',
             },
         ),
         (
@@ -298,8 +300,7 @@ def test_protocol_parsers():
         (
             Config,
             {
-                'c7cf339ac7fb2d5fca9f133beb84d750bd4c9e30',
-                'bebe4d62ce75f866e8621d4d54f2c5262de2eb1a',
+                'da2d8b797568604449695cdcf803e344bdf887eb',
             },
         ),
         # context.py
@@ -652,6 +653,12 @@ def test_protocol_parsers():
                 'ff0c735a388ac8dd7fe300a32c1e36cdf33c0f56',
             },
         ),
+        (
+            _get_client_creator,
+            {
+                '6274e5675ecf13180b5a18daa0242bb71d6437b6',
+            },
+        ),
         # configprovider.py
         (
             SmartDefaultsConfigStoreFactory.merge_smart_defaults,
@@ -670,6 +677,7 @@ def test_protocol_parsers():
             convert_to_response_dict,
             {
                 '5b7701c1f5b3cb2daa6eb307cdbdbbb2e9d33e5f',
+                '0fb9d2f2ab899fad8b2be93223b403f11032670a',
             },
         ),
         (
@@ -701,7 +709,7 @@ def test_protocol_parsers():
         (
             Endpoint._do_get_response,
             {
-                'abad88892d61b22f2a6decffba2e40d070ba9f38',
+                'a9f3ae0f375ba9967425b1fb3e4d45537df4f1e3',
             },
         ),
         (
@@ -783,7 +791,7 @@ def test_protocol_parsers():
         (
             PageIterator.__iter__,
             {
-                'a7e83728338e61ff2ca0a26c6f03c67cbabffc32',
+                '0bfe2ffb0ea63faa1f28cc22250ce626959d05d1',
             },
         ),
         (
@@ -926,7 +934,7 @@ def test_protocol_parsers():
         (
             get_response,
             {
-                '6515f43730b546419695c26d4bc0d198fde54b10',
+                'ea8686ae71fae32410e2f1774e5774d6715dd492',
             },
         ),
         # session.py
@@ -1020,13 +1028,13 @@ def test_protocol_parsers():
         (
             RequestSigner.get_auth,
             {
-                'b78756b9d4f7a5bce9630195d761bab557677225',
+                '13e90d57d536179621ac012ace97e4c2cbaa096e',
             },
         ),
         (
             RequestSigner.get_auth_instance,
             {
-                'b78756b9d4f7a5bce9630195d761bab557677225',
+                '13e90d57d536179621ac012ace97e4c2cbaa096e',
             },
         ),
         (
@@ -1114,7 +1122,7 @@ def test_protocol_parsers():
         (
             create_token_resolver,
             {
-                'b287f4879235a4292592a49b201d2b0bc2dbf401',
+                '7e502da18a02d4f0224568041e3a7ef6a67b2de8',
             },
         ),
         (
@@ -1162,7 +1170,7 @@ def test_protocol_parsers():
         (
             SSOTokenProvider.load_token,
             {
-                'aea8584ef3fb83948ed82f2a2518eec40fb537a0',
+                'fb9114c12952ba47b50e201057e3f5664abdb9d8',
             },
         ),
         # utils.py
@@ -1353,6 +1361,12 @@ def test_protocol_parsers():
                 '148a10274d3268dd42df05d3bcfb98c668f01086',
             },
         ),
+        (
+            create_nested_client,
+            {
+                '619a190d84c4871c0e3c4828b0d6ea607d8b89da',
+            },
+        ),
         # waiter.py
         (
             NormalizedOperationMethod.__call__,
